@@ -3,11 +3,13 @@
 # Description: Document tree
 # Documentation: data_structures.txt
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
+from __future__ import print_function
+
 import re
 import os.path
 import string
@@ -15,7 +17,7 @@ import string
 from Remark.DocumentType_Registry import documentType, strictDocumentType
 from Remark.FileSystem import unixDirectoryName, unixRelativePath, fileExtension
 from Remark.FileSystem import globalOptions, withoutFileExtension
-from Remark.FileSystem import pathSuffixSet, globToRegex, pathExists, findMatchingFiles
+from Remark.FileSystem import pathSuffixSet, globToRegex, directoryExists, findMatchingFiles
 from Remark.Reporting import Reporter, ScopeGuard
 from Remark.Document import Document
 
@@ -64,7 +66,7 @@ class DocumentTree(object):
         self.reporter = reporter
 
     def __iter__(self):
-        return self.documentMap.itervalues()
+        return iter(self.documentMap.values())
         
     def insertDocument(self, relativeName):
         '''
@@ -115,25 +117,25 @@ class DocumentTree(object):
 
         with ScopeGuard(self.reporter, 'Resolving explicit links'):
             self._resolveExplicitLinks()
-            self.reporter.report(['', 'Done.'], 'verbose')
+            self.reporter.report([None, 'Done.', None], 'verbose')
 
         # Resolve implicit links
         
         with ScopeGuard(self.reporter, 'Resolving implicit links'):
             self._resolveImplicitLinks()
-            self.reporter.report(['', 'Done.'], 'verbose')
+            self.reporter.report([None, 'Done.', None], 'verbose')
 
         # Resolve reference links
         
         with ScopeGuard(self.reporter, 'Resolving reference links'):
             self._resolveReferenceLinks()
-            self.reporter.report(['', 'Done.'], 'verbose')
+            self.reporter.report([None, 'Done.', None], 'verbose')
 
         # Link orphans
 
         #with ScopeGuard(self.reporter, 'Linking orphans'):
         self._linkOrphans()
-        #self.reporter.report(['', 'Done.'], 'verbose')
+        #self.reporter.report([None, 'Done.', None], 'verbose')
         
     def findDocumentLocal(self, filePath, searchDirectory):
         '''
@@ -318,7 +320,7 @@ class DocumentTree(object):
         Document objects in those cases where a document file 
         explicitly specifies a parent file using a tag.
         '''
-        for document in self.documentMap.itervalues():
+        for document in self.documentMap.values():
             # Documents which are not associated to a document
             # type are linked to orphan straight away.
             if strictDocumentType(document.extension) == None:
@@ -334,9 +336,8 @@ class DocumentTree(object):
                 parent, unique = self.findDocument(parentName, 
                                                    document.relativeDirectory)
                 if not unique:
-                    self.reporter.reportWarning('Parent is ambiguous for ' + 
-                                            document.relativeName + '. The search was for: ' + 
-                                            parentName,
+                    self.reporter.reportWarning('Parent "' + parentName + '" is ambiguous for ' + 
+                                            document.relativeName + '.',
                                             'ambiguous-parent')
 
                 if parent == None:
@@ -344,9 +345,8 @@ class DocumentTree(object):
                         # If a parent file can't be found, it can be
                         # because of a typo in the tag or a missing file. 
                         # In any case we warn the user.
-                        self.reporter.reportWarning('Parent was not found for ' + 
-                                               document.relativeName + '. The search was for: ' + 
-                                               parentName,
+                        self.reporter.reportWarning('Parent "' + parentName + '" was not found for ' + 
+                                               document.relativeName + '.',
                                                'missing-parent')
                 else:
                     # Parent file was found. Update parent-child pointers.
@@ -392,16 +392,13 @@ class DocumentTree(object):
         # us to find the prefix files. In addition
         # shorter filenames are listed before longer ones.
         
-        def documentCompare(left, right):
-            return cmp(left.relativeName, right.relativeName)
-        
         sortedMap = []
-        for document in self.documentMap.iteritems():
+        for document in self.documentMap.items():
             sortedMap.append(document[1])
-        sortedMap.sort(documentCompare)
+        sortedMap.sort(key = lambda x: x.relativeName)
         
         #for document in sortedMap:
-        #    print document.fileName
+        #    print(document.fileName)
         
         for i in range(0, len(sortedMap)):
             document = sortedMap[i]
@@ -411,7 +408,10 @@ class DocumentTree(object):
             if document.parent != None or 'parentOf' in document.tagSet:
                 continue
             
-            #print 'Implicit find for', document.relativeName
+            self.reporter.report(
+                'Implicit linking for ' + document.relativeName + ' ...', 
+                'debug-implicit')
+
             searchDirectory = document.relativeDirectory
             searchName = withoutFileExtension(document.fileName)
             # The implicit linking only concerns
@@ -470,7 +470,7 @@ class DocumentTree(object):
             
                             # Either the file must be a documentation file
                             # or it must have a parent.                                
-                            #print 'Candidate', thatDocument.relativeName
+                            #print('Candidate', thatDocument.relativeName)
                             if thatDocument.tagString('document_type') == 'RemarkPage':
                                 # We have found a match from a documentation
                                 # file! 
@@ -515,8 +515,10 @@ class DocumentTree(object):
                     newParent = sourceMatches.pop()
                     newParent.insertChild(document)                              
                 
-            #if document.parent != None:
-            #    print document.relativeName, '->', document.parent.relativeName
+            if document.parent != None:
+                self.reporter.report(
+                    'Found ' + document.parent.relativeName + '.', 
+                    'debug-implicit')
         
     def _resolveReferenceLinks(self):
         '''
@@ -525,7 +527,7 @@ class DocumentTree(object):
         specifies a parent file as the parent file of 
         another file. 
         '''
-        for document in self.documentMap.itervalues():
+        for document in self.documentMap.values():
             # Reference linking is done only when no parent has been
             # found through explicit or implicit linking, and
             # a reference link has been specified.
@@ -565,7 +567,7 @@ class DocumentTree(object):
         turns the graph induced by parent-child
         relationships into a tree.
         '''
-        for document in self.documentMap.itervalues():
+        for document in self.documentMap.values():
             if document.parent == None:
                 self.orphan.insertChild(document)
 
@@ -626,8 +628,8 @@ def createDocumentTree(argumentSet, reporter):
     The created document tree.
     '''
 
-    if not pathExists(argumentSet.inputDirectory):
-        reporter.reportError('Input directory ' + inputDirectory + ' does not exist.',
+    if not directoryExists(argumentSet.inputDirectory):
+        reporter.reportError('Input directory ' + argumentSet.inputDirectory + ' does not exist.',
                              'invalid-input')
         return None
 
