@@ -2,14 +2,15 @@
 
 # Description: CodeView document-type
 
-# Remark 1.6.3
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.FileSystem import escapeMarkdown, globalOptions, fileUpToDate
 from Remark.Conversion import saveRemarkToHtml
 from Remark.TagParsers.Dictionary_TagParser import Dictionary_TagParser 
+from Remark.DocumentType_Registry import registerDocumentType
 
 from pygments.lexers import get_lexer_for_filename, get_lexer_by_name
 
@@ -70,8 +71,7 @@ class CodeView_DocumentType(object):
         return fileUpToDate(document.relativeName, documentTree.rootDirectory, 
                             self.outputName(document.relativeName), outputRootDirectory)
 
-    def mathEnabled(self):
-        return False
-
     def outputName(self, fileName):
         return fileName + '.htm'
+
+registerDocumentType('CodeView', CodeView_DocumentType())
