@@ -2,15 +2,14 @@
 
 # Description: Copy document-type
 
-# Remark 1.6.3
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
-import re
-
 from Remark.FileSystem import escapeMarkdown, fileUpToDate, copyIfNecessary
 from Remark.TagParsers.Dictionary_TagParser import Dictionary_TagParser 
+from Remark.DocumentType_Registry import registerDocumentType
 
 class Copy_DocumentType(object):
     def name(self):
@@ -34,8 +33,7 @@ class Copy_DocumentType(object):
         return fileUpToDate(document.relativeName, documentTree.rootDirectory, 
                             self.outputName(document.relativeName), outputRootDirectory)
 
-    def mathEnabled(self):
-        return False
-
     def outputName(self, fileName):
         return fileName
+
+registerDocumentType('Copy', Copy_DocumentType())
