@@ -2,13 +2,14 @@
 
 # Description: DirectoryView document-type
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
-from Remark.FileSystem import changeExtension, fileExists
+from Remark.FileSystem import changeExtension
 from Remark.Conversion import saveRemarkToHtml
+from Remark.DocumentType_Registry import registerDocumentType
 
 class DirectoryView_DocumentType(object):
     def name(self):
@@ -34,8 +35,7 @@ class DirectoryView_DocumentType(object):
     def upToDate(self, document, documentTree, outputRootDirectory):
         return False
 
-    def mathEnabled(self):
-        return False
-
     def outputName(self, fileName):
         return changeExtension(fileName, '.htm')
+
+registerDocumentType('DirectoryView', DirectoryView_DocumentType())
