@@ -2,13 +2,14 @@
 
 # Description: Orphan document-type
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.FileSystem import changeExtension 
 from Remark.Conversion import saveRemarkToHtml
+from Remark.DocumentType_Registry import registerDocumentType
 
 class Orphan_DocumentType(object):
     def name(self):
@@ -35,8 +36,7 @@ class Orphan_DocumentType(object):
     def upToDate(self, document, documentTree, outputRootDirectory):
         return False
 
-    def mathEnabled(self):
-        return False
-
     def outputName(self, fileName):
         return changeExtension(fileName, '.htm')
+
+registerDocumentType('Orphan', Orphan_DocumentType())
