@@ -2,8 +2,8 @@
 
 # Description: RemarkPage document-type
 
-# Remark 1.6.5
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -12,6 +12,7 @@ import re
 from Remark.TagParsers.Remark_TagParser import Remark_TagParser
 from Remark.FileSystem import changeExtension, globalOptions, fileUpToDate
 from Remark.Conversion import saveRemarkToHtml
+from Remark.DocumentType_Registry import registerDocumentType
 
 class RemarkPage_DocumentType(object):
     def __init__(self):
@@ -46,8 +47,7 @@ class RemarkPage_DocumentType(object):
         return fileUpToDate(document.relativeName, documentTree.rootDirectory, 
                             self.outputName(document.relativeName), outputRootDirectory)
 
-    def mathEnabled(self):
-        return True
-
     def outputName(self, fileName):
         return changeExtension(fileName, '.htm')
+
+registerDocumentType('RemarkPage', RemarkPage_DocumentType())
