@@ -3,19 +3,23 @@
 # Description: File-system abstractions
 # Documentation: algorithms.txt
 
-# Remark 1.6.3
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
+from __future__ import print_function
+
 import os.path
 import string
 import codecs
 import shutil
 import fnmatch
 import re
+import six
 
 globalOptions_ = None
+emptyDict = object()
 
 def remarkDirectory():
     '''
@@ -83,28 +87,12 @@ def splitPath(p):
     '''
     Splits a pathname.
 
-    This is a bug-fixed version of os.path.split() from
-    Python 2.7.3. It used os.path.splitdrive() which does not correctly
-    handle long-UNC paths. This is fixed by using os.path.splitunc()
-    instead.
-
     returns: 
     tuple (head, tail) where tail is everything after the final slash.
     Either part may be empty.
     '''
 
-    d, p = os.path.splitunc(p)
-    # set i to index beyond p's last slash
-    i = len(p)
-    while i and p[i-1] not in '/\\':
-        i = i - 1
-    head, tail = p[:i], p[i:]  # now tail has no slashes
-    # remove trailing slashes from head, unless it's all slashes
-    head2 = head
-    while head2 and head2[-1] in '/\\':
-        head2 = head2[:-1]
-    head = head2 or head
-    return d + head, tail
+    return os.path.split(p)
 
 def setGlobalOptions(options):
     '''
@@ -120,36 +108,55 @@ def globalOptions():
     '''
     return globalOptions_;
 
-def htmlDiv(enclosedText, className = '', elementName = 'div', addWhitespace = True):
+def htmlRegion(htmlText):
+    # We need to wrap the html into a region to avoid
+    # it being wrapped into a <p> element.
+    return markdownRegion(
+        htmlText, 
+        {
+            'class' : 'html', 
+            'remark-content' : 'text'
+        })
+
+def markdownRegion(enclosedText, keySet = emptyDict, elementName = 'div'):
     '''
-    Encloses the given text in a <div> block and gives it a
-    html-class, so that it can be styled with CSS.
+    Encloses the given text in a Markdown region (Remark extension)
+
+    !!! <elementName aKey="aValue" bKey="bValue" ...>
+        enclosedText
 
     enclosedText (list of strings):
     The text to enclose.
 
-    className:
-    The name of the html-class to give to the div block.
+    keySet (string:string):
+    A set of key-value pairs to apply to the region.
+
+    elementName (string):
+    The name of the region element.
     '''
+    if keySet is emptyDict: keySet = dict()
+
+    regionText = '!!! <' 
+    regionText += elementName
+
+    for (key, value) in keySet.items():
+        regionText += ' ' + key.strip() + ' = "' + value + '"'
+
+    regionText += '>'
+    
     text = []
-    text.append('')
+    text.append(regionText)
 
-    if className != '':
-        text.append('<' + elementName + ' class = "' + className + '">')
-    else:
-        text.append('<' + elementName + '>')
-    
-    if addWhitespace:
-        # Note that this empty line is essential for Markdown
-        # not to interpret the following stuff as html.
-        text.append('')
-    
-    text += enclosedText
-    
-    if addWhitespace:
-        text.append('')
+    for line in enclosedText:
+        text.append('\t' + line)
 
-    text.append('</' + elementName + '>')
+    # When the text is enclosed in a region inline,
+    # as in [[Verbatim: like this]], we need
+    # the new-line to avoid the succeeding 
+    # content being appended inside the region.
+    # Otherwise this new-line is extraneous,
+    # and looks a bit ugly in the Markdown 
+    # source output.
     text.append('')
 
     return text
@@ -171,7 +178,7 @@ def globToRegex(glob):
     returns (string):
     The converted regular expression.
     '''
-    if not isinstance(glob, basestring):
+    if not isinstance(glob, six.string_types):
         regexSet = []
         for line in glob:
             regexSet.append(globToRegex(line))
@@ -200,7 +207,7 @@ def combineRegex(regex):
     The combined regular expression.
     '''
     regexString = ''
-    if isinstance(regex, basestring):
+    if isinstance(regex, six.string_types):
         regexString = regex.strip()
     else:
         regexSet = []
@@ -316,9 +323,9 @@ def readFile(fileName, maxSize = -1):
         # part of the Remark documentation. Refuse to read
         # such files.
         print
-        print 'Warning:', fileName, 
-        print 'is larger than', maxSize, 'bytes (it is', size, 'bytes).',
-        print 'Ignoring it.'
+        print('Warning:', fileName, end = ' ')
+        print('is larger than', maxSize, 'bytes (it is', size, 'bytes).', end = ' ')
+        print('Ignoring it.')
         return []
         
     # Read the file into memory
@@ -328,9 +335,9 @@ def readFile(fileName, maxSize = -1):
             text = file.readlines()
     except:
         print
-        print 'Warning:', fileName,
-        print ' could not be read for some reason.',
-        print ' Ignoring it.'
+        print('Warning:', fileName, end = ' ')
+        print('could not be read for some reason.', end = ' ')
+        print('Ignoring it.')
         return []
 
     for i in range(0, len(text)):
@@ -378,6 +385,12 @@ def pathExists(path):
     '''
     return os.path.exists(longPath(path))
 
+def directoryExists(path):
+    '''
+    Returns pathExists(path) and os.path.isdir(longPath(path))
+    '''
+    return pathExists(path) and os.path.isdir(longPath(path))
+
 def copyTree(inputDirectory, outputDirectory):
     '''
     Calls shutil.copytree(longPath(inputDirectory), longPath(outputDirectory)).
@@ -511,9 +524,10 @@ def fileModificationTime(filePath):
 
 def fileExists(inputRelativeName, inputDirectory):
     '''
-    Returns pathExists(os.path.join(inputDirectory, inputRelativeName)).
+    Returns pathExists(os.path.join(inputDirectory, inputRelativeName)) and os.path.isfile(longPath(path)).
     '''
-    return pathExists(os.path.join(inputDirectory, inputRelativeName))
+    path = os.path.join(inputDirectory, inputRelativeName)
+    return pathExists(path) and os.path.isfile(longPath(path))
 
 def fileUpToDate(inputRelativeName, inputDirectory,
                  outputRelativeName, outputDirectory):
@@ -528,7 +542,7 @@ def fileUpToDate(inputRelativeName, inputDirectory,
     outputFilePath = os.path.join(outputDirectory, outputRelativeName)
 
     if not pathExists(inputFilePath):
-        print 'Error: fileUpToDate: the input file ' + inputRelativeName + ' does not exist.'
+        print('Error: fileUpToDate: the input file ' + inputRelativeName + ' does not exist.')
         return False
 
     # The output file is up-to-date if it exists and has a 
@@ -541,7 +555,7 @@ def unixDirectoryName(name):
     Returns a normalized unix-style directory-name of the given 
     directory-name (unix-style or not).
     '''
-    return string.replace(os.path.normpath(name), '\\', '/')                
+    return os.path.normpath(name).replace('\\', '/')                
 
 def fileExtension(fileName):
     '''
