@@ -3,11 +3,13 @@
 # Description: Macro registry
 # Documentation: data_structures.txt
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
+from __future__ import print_function
+
 _macroMap = dict()
 
 def registerMacro(name, macro):
@@ -17,7 +19,7 @@ def registerMacro(name, macro):
     See also:
     findMacro()
     '''
-    #print "Macro '" + name + "' registered."
+    #print("Macro '" + name + "' registered.")
     _macroMap[name] = macro
 
 def findMacro(name):
