@@ -3,8 +3,8 @@
 # Description: Body macro
 # Detail: Reads a document from file.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -23,9 +23,6 @@ class Body_Macro(object):
 
         return text
     
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return True
     
