@@ -3,8 +3,8 @@
 # Description: Comment macro
 # Detail: Consumes its input and produces no output.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -20,9 +20,6 @@ class Comment_Macro(object):
         text = []
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
