@@ -3,8 +3,8 @@
 # Description: Copy macro
 # Detail: Copies the input to output.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -18,9 +18,6 @@ class Copy_Macro(object):
         text = parameter
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return True
 
