@@ -3,8 +3,8 @@
 # Description: DirectoryLink macro
 # Detail: Generates a relative link to the containing directory.
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -54,9 +54,6 @@ class DirectoryLink_Macro(object):
             
         return text
     
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
