@@ -3,13 +3,13 @@
 # Description: DocChildren macro
 # Detail: Generates links to documentation children.
 
-# Remark 1.6.5
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro, findMacro
-from Remark.FileSystem import unixRelativePath, htmlDiv
+from Remark.FileSystem import unixRelativePath
 from Remark.DocumentType_Registry import outputDocumentName
 
 class DocChildren_Macro(object):
@@ -71,11 +71,8 @@ class DocChildren_Macro(object):
 
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
-        return True
+        return False
 
     def htmlHead(self, remark):
         return []                
