@@ -3,8 +3,8 @@
 # Description: DocumentTree macro
 # Detail: Generates a hierarchical link-tree of the document-tree. 
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -12,7 +12,7 @@ import fnmatch
 import re
 
 from Remark.Macro_Registry import registerMacro
-from Remark.FileSystem import htmlDiv, globToRegex, combineRegex
+from Remark.FileSystem import markdownRegion, globToRegex, combineRegex
 
 class DocumentTree_Macro(object):
     def name(self):
@@ -41,7 +41,7 @@ class DocumentTree_Macro(object):
         self._parse(self.includeRegex, self.includeMap, lambda x: x + r'\Z')
 
         self.includeFilter = {}
-        for tagName, regex in self.includeMap.iteritems():
+        for tagName, regex in self.includeMap.items():
             self.includeFilter[tagName] = re.compile(combineRegex(regex))
 
         self.excludeMap = {}
@@ -49,7 +49,7 @@ class DocumentTree_Macro(object):
         self._parse(self.excludeRegex, self.excludeMap, lambda x: x + r'\Z')
 
         self.excludeFilter = {}
-        for tagName, regex in self.excludeMap.iteritems():
+        for tagName, regex in self.excludeMap.items():
             self.excludeFilter[tagName] = re.compile(combineRegex(regex))
 
         rootDocument, unique = self.documentTree.findDocument(self.rootName, 
@@ -70,15 +70,12 @@ class DocumentTree_Macro(object):
         if text == ['']:
             return []
 
-        text = htmlDiv(text, self.className)
-
-        return text
-
-    def outputType(self):
-        return 'remark'
+        return markdownRegion(
+            remark.convert(text), 
+            {'class' : self.className})
 
     def expandOutput(self):
-        return True
+        return False
 
     def htmlHead(self, remark):
         return []                
@@ -121,8 +118,8 @@ class DocumentTree_Macro(object):
             self.visitedSet.add(document)
 
         # Sort the children by link-description.
-        childSet = document.childSet.values()
-        childSet.sort(lambda x, y: cmp(x.linkDescription(), y.linkDescription()))        
+        childSet = list(document.childSet.values())
+        childSet.sort(key = lambda x: x.linkDescription())
 
         # Recurse to output the children, but only
         # if we have not visited this document before.
@@ -139,7 +136,7 @@ class DocumentTree_Macro(object):
 
         # Filter by exclusion.
         exclude = False
-        for tagName, tagRegex in self.excludeFilter.iteritems():
+        for tagName, tagRegex in self.excludeFilter.items():
             excludeValue = document.tagString(tagName).strip()
             if tagRegex.match(excludeValue) != None:
                 exclude = True
@@ -147,7 +144,7 @@ class DocumentTree_Macro(object):
 
         # Filter by inclusion.
         include = False
-        for tagName, tagRegex in self.includeFilter.iteritems():
+        for tagName, tagRegex in self.includeFilter.items():
             includeValue = document.tagString(tagName).strip()
             if tagRegex.match(includeValue) != None:
                 include = True
