@@ -3,15 +3,18 @@
 # Description: EquationSet macro
 # Detail: Presents multiple equations.
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro
-from Remark.FileSystem import htmlDiv
+from Remark.FileSystem import markdownRegion
 
 class EquationSet_Macro(object):
+    def __init__(self, wrapMacro):
+        self.wrapMacro = wrapMacro
+
     def name(self):
         return 'EquationSet'
 
@@ -26,17 +29,17 @@ class EquationSet_Macro(object):
             cleanLine = line.strip()
             if cleanLine != '':
                 # An ordered list of equations.
-                text.append(' 1. [[Equation]]: ' + cleanLine);
+                equationText = remark.macro(self.wrapMacro, [cleanLine])
+                if len(equationText) > 0:
+                    equationText[0] = '1. ' + equationText[0]
+                text += equationText
 
-        text = htmlDiv(text, className)
+        text =  markdownRegion(text, {'class' : className})
 
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
-        return True
+        return False
 
     def htmlHead(self, remark):
         return []                
@@ -44,7 +47,6 @@ class EquationSet_Macro(object):
     def postConversion(self, remark):
         None
 
-registerMacro('EquationSet', EquationSet_Macro())
-
-
-
+registerMacro('EquationSet', EquationSet_Macro('Equation'))
+registerMacro('EquationSet_Latex', EquationSet_Macro('Equation_Latex'))
+registerMacro('EquationSet_Latex_D', EquationSet_Macro('Equation_Latex_D'))
