@@ -2,38 +2,34 @@
 
 # Description: Example macro
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro
+from Remark.FileSystem import markdownRegion
 
 class Example_Macro(object):
     def name(self):
         return 'Example'
 
     def expand(self, parameter, remark):
-        text = []
-        
-        text.append('')
-        text.append('This')
-        text.append('')
-        text.append('[[Verbatim]]:')
-        for line in parameter:
-            text.append('\t' + line)
-        text.append('produces this')
-        text.append('')
-        text += parameter
+        scope = remark.scopeStack.top()
+
+        className = scope.getString('Example.class_name', 'Example')
+
+        text = remark.macro('Verbatim', parameter)
         text.append('')
 
+        text += markdownRegion(
+            remark.convert(parameter), 
+            {'class' : className})
+
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
-        return True
+        return False
 
     def htmlHead(self, remark):
         return []                
