@@ -3,8 +3,8 @@
 # Description: FileLink macro
 # Detail: Generates a link to a document in the document tree.
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -40,9 +40,6 @@ class FileLink_Macro(object):
             
         return text
     
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
