@@ -3,15 +3,15 @@
 # Description: Gallery macro
 # Detail: Generates an image gallery with thumbnails.
 
-# Remark 1.6.3
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro
 from Remark.FileSystem import unixRelativePath, unixDirectoryName, changeExtension
 from Remark.FileSystem import fileExtension, copyIfNecessary, createDirectories, copyTree
-from Remark.FileSystem import pathExists, fileModificationTime, remarkDirectory
+from Remark.FileSystem import pathExists, fileModificationTime, remarkDirectory, htmlRegion
 
 import sys
 import os.path
@@ -157,7 +157,7 @@ class Gallery_Macro(object):
             # Find out thumbnail names.
             # The used hash does not matter, but it must always give the same
             # hash for the same relative-name.
-            hashString = hashlib.md5(input.relativeName).hexdigest()[0 : 16]
+            hashString = hashlib.md5(input.relativeName.encode('utf-8')).hexdigest()[0 : 16]
             thumbRelativeName = 'remark_files/thumbnails/' + changeExtension(input.fileName, '-' + hashString + '.png')
             thumbLinkName = unixRelativePath(document.relativeDirectory, thumbRelativeName)
             if pixelDocument == None:
@@ -227,7 +227,7 @@ class Gallery_Macro(object):
                         if pixelDocument != input:
                             message += ' from ' + pixelDocument.relativeName
                         message += '.'
-                        remark.report(['', message],
+                        remark.report([None, message],
                                      'verbose')
                 except IOError as err: 
                     remark.reportWarning('Cannot create a thumbnail for ' + input.relativeName + 
@@ -236,10 +236,7 @@ class Gallery_Macro(object):
 
         text.append('</div>')
         
-        return text
-
-    def outputType(self):
-        return 'html'
+        return htmlRegion(text)
 
     def expandOutput(self):
         return False
