@@ -3,23 +3,20 @@
 # Description: Html macro
 # Detail: Copies the input to output and treats it as html.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro
+from Remark.FileSystem import htmlRegion
 
 class Html_Macro(object):
     def name(self):
         return 'Html'
 
     def expand(self, parameter, remark):
-        text = parameter
-        return text
-
-    def outputType(self):
-        return 'html'
+        return htmlRegion(parameter)
 
     def expandOutput(self):
         return False
