@@ -3,15 +3,15 @@
 # Description: Index macro
 # Detail: Generates a html file to traverse the directory tree directly. 
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 import string
 import os.path
 
-from Remark.FileSystem import unixRelativePath, htmlDiv, escapeMarkdown
+from Remark.FileSystem import unixRelativePath, markdownRegion, escapeMarkdown
 from Remark.FileSystem import unixDirectoryName, listDirectory
 from Remark.Macro_Registry import registerMacro
 from Remark.DocumentType_Registry import outputDocumentName
@@ -66,15 +66,12 @@ class Index_Macro(object):
                     
         text.append('')
 
-        text = htmlDiv(text, className)
-
-        return text
-
-    def outputType(self):
-        return 'remark'
+        return markdownRegion(
+            remark.convert(text), 
+            {'class' : className})
 
     def expandOutput(self):
-        return True
+        return False
 
     def htmlHead(self, remark):
         return []                
