@@ -3,8 +3,8 @@
 # Description: Link macro
 # Detail: Generates a link to a document in the document tree.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -39,9 +39,6 @@ class Link_Macro(object):
             
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
