@@ -3,8 +3,8 @@
 # Description: Parent macro
 # Detail: Generates a link to the parent documentation.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -27,9 +27,6 @@ class Parent_Macro(object):
 
         return text
 
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
