@@ -3,8 +3,8 @@
 # Description: ReadFile macro
 # Detail: Reads a plain-text file.
 
-# Remark 1.6.3
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -56,9 +56,6 @@ class ReadFile_Macro(object):
 
         return text
     
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return True
     
