@@ -3,8 +3,8 @@
 # Description: Ref macro
 # Detail: Finds the relative output name of a file in document tree.
 
-# Remark 1.6.5
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -38,9 +38,6 @@ class Ref_Macro(object):
             
         return text
     
-    def outputType(self):
-        return 'remark'
-
     def expandOutput(self):
         return False
 
