@@ -3,31 +3,30 @@
 # Description: Verbatim macro
 # Detail: Reinterprets input as preformatted text.
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
 from Remark.Macro_Registry import registerMacro
-
-from Remark.FileSystem import htmlDiv
+from Remark.FileSystem import markdownRegion
 
 class Verbatim_Macro(object):
     def name(self):
         return 'Verbatim'
 
     def expand(self, parameter, remark):
-        text = []
+        scope = remark.scopeStack.top()
 
+        className = scope.getString('Verbatim.class_name', 'Verbatim')
+
+        text = []
         for line in parameter:
             text.append('\t' + line)
 
-        text.append('')
-
-        return text
-
-    def outputType(self):
-        return 'remark'
+        return markdownRegion(
+            text, 
+            {'class' : className})
 
     def expandOutput(self):
         return False
