@@ -3,11 +3,13 @@
 # Description: Converts Remark to Markdown and html
 # Documentation: algorithms.txt
 
-# Remark 1.6.4
-# Copyright (c) 2009 - 2014
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
+from __future__ import print_function
+
 import re
 import string
 import os
@@ -17,8 +19,9 @@ import codecs
 import copy
 import traceback
 import time
+import six
 
-from Remark.Version import asciiMathMlName, remarkVersion
+from Remark.Version import remarkVersion
 from Remark.Macro_Registry import findMacro
 from Remark.FileSystem import changeExtension, unixDirectoryName, copyIfNecessary
 from Remark.FileSystem import globalOptions, unixRelativePath, writeFile
@@ -26,6 +29,8 @@ from Remark.Reporting import Reporter, ScopeGuard
 from Remark.DocumentType_Registry import documentType, outputDocumentName
 from Remark.DocumentTree import createDocumentTree
 
+emptyList = object()
+
 class Scope(object):
     def __init__(self, parent, name):
         self.parent = parent
@@ -36,7 +41,7 @@ class Scope(object):
         return self.name
     
     def insert(self, name, data):
-        #print 'Inserted', name, data
+        #print('Inserted', name, data)
         self.nameSet[name] = data
         
     def append(self, name, data):
@@ -58,7 +63,7 @@ class Scope(object):
         return self.nameSet.get(name)
     
     def search(self, name):
-        #print 'Recursive search for', name
+        #print('Recursive search for', name)
         result = self.shallowSearch(name)        
         if result != None:
             return result
@@ -67,7 +72,7 @@ class Scope(object):
         return None
     
     def searchScope(self, name):
-        #print 'Recursive search for', name
+        #print('Recursive search for', name)
         result = self.shallowSearch(name)        
         if result != None:
             return self
@@ -75,7 +80,8 @@ class Scope(object):
             return self.parent.searchScope(name)
         return self
 
-    def get(self, name, defaultValue = []):
+    def get(self, name, defaultValue = emptyList):
+        if defaultValue is emptyList: defaultValue = []
         variable = self.search(name)
         if variable == None:
             return defaultValue
@@ -104,7 +110,7 @@ class Scope(object):
             value = defaultValue
         
         if value == None:
-            print 'Warning: Could not convert', name, 'to an integer. Using default.'
+            print('Warning: Could not convert', name, 'to an integer. Using default.')
             value = defaultValue
             
         return value
@@ -114,14 +120,14 @@ class ScopeStack(object):
         self.scopeStack = []
         
     def open(self, name):
-        #print 'Scope opened.'
+        #print('Scope opened.')
         parent = None
         if len(self.scopeStack) > 0:
             parent = self.top()                
         self.scopeStack.append(Scope(parent, name))
         
     def close(self):
-        #print 'Scope closed.'
+        #print('Scope closed.')
         self.scopeStack.pop()
         
     def top(self):
@@ -131,14 +137,14 @@ class ScopeStack(object):
         return self.scopeStack[0]
 
     def printScopes(self):
-        print len(self.scopeStack)
+        print(len(self.scopeStack))
         tabs = 0;
         for scope in self.scopeStack:
-            print '\t' * tabs
-            print scope.name, 'scope:'
+            print('\t' * tabs)
+            print(scope.name, 'scope:')
             print
-            for entry in scope.nameSet.iteritems():
-                print entry[0], ':', entry[1]
+            for entry in scope.nameSet.items():
+                print(entry[0], ':', entry[1])
             tabs += 1
 
 class MacroInvocation(object):
@@ -296,11 +302,12 @@ class Remark(object):
         # Form the Markdown link.
         text = '[' + description + '][' + name + ']'
         
-        # We defer defining the link because the link
-        # could be an inline link. Instead we store the
+        # To maintain pretty Markdown output, we store the
         # definitions so that we can output them to the
         # end of the document. 
         self.linkSet.append((name, unixDirectoryName(htmlLink)))
+
+        #text = '[' + description + ']<' + unixDirectoryName(htmlLink) + '>'
         
         return text
     
@@ -310,6 +317,9 @@ class Remark(object):
     def reportError(self, text, type):
         self.reporter.reportError(text, type)
 
+    def reportDebug(self, text, type):
+        self.reporter.reportDebug(text, type)
+
     def report(self, text, type):
         self.reporter.report(text, type)
         
@@ -372,7 +382,7 @@ class Remark(object):
 
         # Extract an inline parameter.
         if hasInlineParameters:
-            parameter = string.strip(inlineParameter)
+            parameter = inlineParameter.strip()
             parameterSet.append(parameter)
 
         # Extract a one-line parameter.
@@ -381,7 +391,7 @@ class Remark(object):
             # If the parameter consists of all
             # whitespace, it is a multi-line parameter
             # so ignore that case here.
-            parameter = string.strip(onelineParameter)
+            parameter = onelineParameter.strip()
             if parameter != '':
                 # One-line parameter
                 hasOnelineParameter = True
@@ -419,37 +429,28 @@ class Remark(object):
             # is marked by a line which is not all whitespace
             # and has no indentation. 
             if (_leadingTabs(text[endRow], globalOptions().tabSize)[0] == 0 and 
-                string.strip(text[endRow]) != ''):
+                text[endRow].strip() != ''):
                 break
             endRow += 1
-            
+
+        # However, we do not include those whitespace-lines _at the end_
+        # that lack indentation. Excluding these lines is important;
+        # otherwise a following header-line could be interpreted as
+        # a paragraph followed by a separator-line, since there is no
+        # separating whitespace. It is also important to preserve those
+        # empty-lines which are indented; that whitespace may be significant
+        # for a macro.
+        while (endRow > startRow and 
+            _leadingTabs(text[endRow - 1], globalOptions().tabSize)[0] == 0 and
+            text[endRow - 1].strip() == ''):
+            endRow -= 1
+
         # Copy the parameter and remove the indentation from it.
         parameterSet = [_removeLeadingTabs(line, globalOptions().tabSize, 1) 
             for line in text[startRow : endRow]]
     
-        # Remove the possible empty trailing parameter lines.
-        nonEmptyLines = len(parameterSet)
-        while nonEmptyLines > 0:
-            if string.strip(parameterSet[nonEmptyLines - 1]) == '':
-                nonEmptyLines -= 1
-            else:
-                break
-            
-        parameterSet[nonEmptyLines :] = []
-
         return parameterSet
 
-    def addDummyHtmlNewLines(self, htmlText):
-        for j in range(0, len(htmlText)):
-            if string.strip(htmlText[j]) == '':
-                # The Markdown syntax interprets
-                # empty lines as ending the html
-                # block. This tricks avoids that
-                # behaviour. Note that it is not
-                # equivalent to simply remove the 
-                # line.
-                htmlText[j] = '<span class="p"></span>'
-
     def expandBuiltInMacro(self, macroNameSet, parameterSet, scope):
         '''
         Expands a built-in macro.
@@ -627,6 +628,15 @@ class Remark(object):
 
         self.recursionDepth += 1
 
+        # maxRecursionDepth = 100
+        # if self.recursionDepth > maxRecursionDepth:
+        #     self.reportDebug(
+        #         'Macro expansion recursion exceeded ' + 
+        #         str(maxRecursionDepth) + 
+        #         ' levels.', 
+        #         'debug-recursion')
+        #     sys.exit(0)
+
         # This function expands the given macro in
         # the current position.
         scope = self.scopeStack.top()
@@ -637,7 +647,7 @@ class Remark(object):
         expandOutput = True
 
         # Retrieve the macro names and parameters.
-        macroNameSet = string.split(macroInvocation.name)
+        macroNameSet = macroInvocation.name.split()
         macroName = macroNameSet[0]
         parameterSet = macroInvocation.parameterSet
         
@@ -665,12 +675,6 @@ class Remark(object):
                     # Mark the macro as used.
                     self.usedMacroSet.append(macro)
                     
-                    # If the output is meant to be html,
-                    # we need to add some dummy html newlines
-                    # for Markdown.
-                    if macro.outputType() == 'html':
-                        self.addDummyHtmlNewLines(macroText)
-
                     # The output of the macro is either
                     # recursively expanded or not.
                     # The macro suggests a default for this
@@ -737,10 +741,8 @@ class Remark(object):
         text (list of strings):
         The Remark text to convert.
         
-        returns (list of strings, set of documents):
-        The converted Markdown text and the set of 
-        document-objects from which the converted text 
-        is dependent on.
+        returns (list of strings):
+        The converted Markdown text.
         '''
 
         # The strategy in this function is to trace the 'text' 
@@ -756,13 +758,34 @@ class Remark(object):
             line = ' ' * column + text[row][column :]
             
             # The indentation macro is invoked if and only if
-            # * a non-empty line starts with a tab, and
-            # * the line in 1 is preceded by a row of whitespace.
-            indentationMacro = (len(line) > 0 and 
-                                line[0] == '\t' and 
-                                line.strip() != '' and
-                                row > 0 and
-                                text[row - 1].strip() == '')
+            # 1) a non-empty line starts with a tab, and
+            tabbedNonEmpty = (
+                line.strip() != '' and 
+                line[0] == '\t')
+
+            # 2) the line in 1 is preceded by a row of whitespace, and
+            precededByWhitespace = (
+                row == 0 or
+                text[row - 1].strip() == '')
+
+            # 3) the first non-empty line preceding line in 1 does
+            # not start with a tab.
+            indentationMacro = False
+            if tabbedNonEmpty and precededByWhitespace:
+                # The first two conditions are satisfied.
+                # This line possibly starts an indentation macro.
+
+                # Check the third condition.
+                indentationMacro = True
+                for i in range(row - 2, -1, -1):
+                    if text[i].strip() != '':
+                        # The line is non-empty.
+                        if text[i][0] == '\t':
+                            # The first non-empty line starts
+                            # with a tab. Therefore this line
+                            # does not start an indentation macro.
+                            indentationMacro = False
+                        break
 
             if indentationMacro:
                 # There is an indentation-macro invocation here.
@@ -813,14 +836,28 @@ class Remark(object):
                 if match == None:
                     # There is no macro on the line: 
                     # copy the line verbatim.
-                    newText[-1] += line[column :]
+
+                    if column == 0 and line.strip() == '':
+                        # The line is all whitespace. This
+                        # signifies a new-line.
+                        if newText[-1].strip() != '':
+                            # A new-line is to be started
+                            # only if there is already content
+                            # on the latest-line.
+                            newText.append('')
+                    else:
+                        # Concatenate the rest of the line to
+                        # the latest line.
+                        newText[-1] += line[column :]
+
+                    # In any case, start a new line.
                     newText.append('')
                     row += 1
-                    column = 0              
+                    column = 0
                     continue
     
-                #print 'I read:'
-                #print match.group(0)
+                #print('I read:')
+                #print(match.group(0))
 
                 # Yes, there is a macro on the line.
                 # First copy the possible verbatim content.
@@ -830,13 +867,29 @@ class Remark(object):
             
                 # Find out the whole macro invocation.
                 macroInvocation = self.extractMacro(row, match, text)
-            
-            #print 'Macro invocation:'
-            #print macroInvocation.name
-            #print macroInvocation.beginRow, macroInvocation.beginColumn
-            #print macroInvocation.endRow, macroInvocation.endColumn
-            #for parameterLine in macroInvocation.parameterSet:
-            #    print parameterLine
+
+            # Debug-report the macro-invocation.
+            underlining = '-' * len(macroInvocation.name)
+
+            invocationText = []
+            invocationText.append(
+                macroInvocation.name + ' ' +
+                '(' + 
+                    str(macroInvocation.beginRow + 1) + 
+                    ', ' +
+                    str(macroInvocation.beginColumn + 1) + 
+                ')' +
+                ' -> ' +
+                '(' + 
+                    str(macroInvocation.endRow + 1) + 
+                    ', ' +
+                    str(macroInvocation.endColumn + 1) + 
+                ')')
+            if len(macroInvocation.parameterSet) > 0:
+                invocationText.append(underlining)
+                invocationText += macroInvocation.parameterSet
+                invocationText.append(underlining)
+            self.reportDebug(invocationText, 'debug-macro-invocation')
 
             # See if the user requests the macro parameter to be 
             # expanded before the macro.
@@ -849,17 +902,19 @@ class Remark(object):
             # Recursively expand the macro.
             macroText = self.expandMacro(macroInvocation)
 
-            #print 'I write:'
-            #for line in macroText:
-            #    print line
-           
+            # Debug-report the result of the macro-expansion.
+            if len(macroText) > 0:
+                self.reportDebug([underlining] + macroText + [underlining], 'debug-macro-expansion')
+            else:
+                self.reportDebug('', 'debug-macro-expansion')
+
             # Append the first line of the macro expansion to 
             # the end of the latest line.
             newText[-1] += macroText[0]
             # Append the other lines of the macro expansion to
             # the following lines.
             newText += macroText[1 :]
-            
+
             # Move on.
             row = macroInvocation.endRow
             column = macroInvocation.endColumn
@@ -867,7 +922,7 @@ class Remark(object):
         # The last '' is extraneous.
         if newText[-1] == '':
             newText[-1 :] = []
-        
+
         return newText
     
     def macro(self, macroName, macroParameter = ''):
@@ -884,7 +939,7 @@ class Remark(object):
         The output of the macro.
         '''
         text = ['[[' + macroName + ']]']
-        if isinstance(macroParameter, basestring):
+        if isinstance(macroParameter, six.string_types):
             if macroParameter.strip() != '':
                 text[0] += ': ' + macroParameter
         elif len(macroParameter) > 0:
