@@ -1,8 +1,8 @@
 # Description: Version-specific constants
 # Documentation: implementation.txt
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.7.8
+# Copyright (c) 2009 - 2021
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -10,11 +10,5 @@ def remarkVersion():
     '''
     Returns the version of Remark as a string.
     '''
-    return '1.6.0'
+    return '1.7.8'
 
-def asciiMathMlName():
-    '''
-    Returns the name of the Javascript file to
-    use for AsciiMathML.
-    '''
-    return 'ASCIIMathMLwFallback.js'
